package com.ruoyi.web.modules.trading.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Param;
import com.ruoyi.web.modules.trading.domain.BizMarketStall;

/**
 * 市场栏位 Mapper
 */
public interface BizMarketStallMapper
{
    BizMarketStall selectBizMarketStallById(Long id);

    BizMarketStall selectBizMarketStallByIdAny(Long id);

    String selectMaxStallCodeForUpdate();

    List<BizMarketStall> selectBizMarketStallList(BizMarketStall query);

    int insertBizMarketStall(BizMarketStall row);

    int updateBizMarketStall(BizMarketStall row);

    int logicDeleteBizMarketStallByIds(@Param("ids") Long[] ids, @Param("updateBy") String updateBy);
}
